summaryrefslogtreecommitdiff
path: root/receiver.h
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2005-01-16 14:40:47 +0100
committerKlaus Schmidinger <vdr@tvdr.de>2005-01-16 14:40:47 +0100
commitc522225344fdcbea2ec2946695d43a5dfa6c175a (patch)
treeeac64a12b227614c86183257e3ea728e80986f0b /receiver.h
parent9423c636a25dcdc2531d51551aff33cf93abc095 (diff)
downloadvdr-c522225344fdcbea2ec2946695d43a5dfa6c175a.tar.gz
vdr-c522225344fdcbea2ec2946695d43a5dfa6c175a.tar.bz2
Recording and Transfer Mode now handle more than 2 audio PIDs
Diffstat (limited to 'receiver.h')
-rw-r--r--receiver.h42
1 files changed, 22 insertions, 20 deletions
diff --git a/receiver.h b/receiver.h
index 8ad8bc06..959f6d61 100644
--- a/receiver.h
+++ b/receiver.h
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: receiver.h 1.2 2002/07/28 11:22:01 kls Exp $
+ * $Id: receiver.h 1.3 2005/01/16 14:05:10 kls Exp $
*/
#ifndef __RECEIVER_H
@@ -12,7 +12,7 @@
#include "device.h"
-#define MAXRECEIVEPIDS 16 // the maximum number of PIDs per receiver
+#define MAXRECEIVEPIDS 64 // the maximum number of PIDs per receiver
class cReceiver {
friend class cDevice;
@@ -21,30 +21,32 @@ private:
int ca;
int priority;
int pids[MAXRECEIVEPIDS];
+ int numPids;
bool WantsPid(int Pid);
protected:
void Detach(void);
virtual void Activate(bool On) {}
- // This function is called just before the cReceiver gets attached to
- // (On == true) or detached from (On == false) a cDevice. It can be used
- // to do things like starting/stopping a thread.
- // It is guaranteed that Receive() will not be called before Activate(true).
+ ///< This function is called just before the cReceiver gets attached to
+ ///< (On == true) or detached from (On == false) a cDevice. It can be used
+ ///< to do things like starting/stopping a thread.
+ ///< It is guaranteed that Receive() will not be called before Activate(true).
virtual void Receive(uchar *Data, int Length) = 0;
- // This function is called from the cDevice we are attached to, and
- // delivers one TS packet from the set of PIDs the cReceiver has requested.
- // The data packet must be accepted immediately, and the call must return
- // as soon as possible, without any unnecessary delay. Each TS packet
- // will be delivered only ONCE, so the cReceiver must make sure that
- // it will be able to buffer the data if necessary.
+ ///< This function is called from the cDevice we are attached to, and
+ ///< delivers one TS packet from the set of PIDs the cReceiver has requested.
+ ///< The data packet must be accepted immediately, and the call must return
+ ///< as soon as possible, without any unnecessary delay. Each TS packet
+ ///< will be delivered only ONCE, so the cReceiver must make sure that
+ ///< it will be able to buffer the data if necessary.
public:
- cReceiver(int Ca, int Priority, int NumPids, ...);
- // Creates a new receiver that requires conditional access Ca and has
- // the given Priority. NumPids defines the number of PIDs that follow
- // this parameter. If any of these PIDs are 0, they will be silently ignored.
- // The total number of non-zero PIDs must not exceed MAXRECEIVEPIDS.
- // Priority may be any value in the range 0..99. Negative values indicate
- // that this cReceiver may be detached at any time (without blocking the
- // cDevice it is attached to).
+ cReceiver(int Ca, int Priority, int Pid, const int *Pids1 = NULL, const int *Pids2 = NULL, const int *Pids3 = NULL);
+ ///< Creates a new receiver that requires conditional access Ca and has
+ ///< the given Priority. Pid is a single PID (typically the video PID), while
+ ///< Pids1...Pids3 are pointers to zero terminated lists of PIDs.
+ ///< If any of these PIDs are 0, they will be silently ignored.
+ ///< The total number of non-zero PIDs must not exceed MAXRECEIVEPIDS.
+ ///< Priority may be any value in the range 0..99. Negative values indicate
+ ///< that this cReceiver may be detached at any time (without blocking the
+ ///< cDevice it is attached to).
virtual ~cReceiver();
};